import * as Phoenix from "phoenix";
export declare class Conversation {
    private audioContext;
    private audioInterval;
    private audioSendInterval;
    private audioSourceConstraints;
    private channel;
    private conversationId;
    private pubsub;
    private recorder;
    private socket;
    /**
     * @ignore
     */
    constructor(conversationId: string, identifier: string, socket: Phoenix.Socket, options: ConversationOptions);
    /**
     * Get the recording status of the conversation.
     *
     * @category Recording
     * @example
     * ```javascript
     * const uhlive = new Uhlive("my-token);
     * uhlive
     *     .join("my-conversation")
     *     .isRecording(); // true
     * ```
     *
     * @example
     * ```js
     * const uhlive = new Uhlive("my-token);
     * uhlive
     *     .join("my-conversation", {readonly: true})
     *     .isRecording(); // false
     * ```
     */
    isRecording(): boolean;
    /**
     * @ignore
     */
    join(): Conversation;
    /**
     * @ignore
     */
    leave(): void;
    /**
     * Subscribe to Conversation `onClose` event.
     *
     * @category Events
     * @example
     * ```js
     * const uhlive = new Uhlive("my-token");
     * const conversation = uhlive.join("test");
     * conversation.onClose((msg) => console.log(msg))
     * ```
     */
    onClose(callback: (payload: any) => void): this;
    /**
     * Subscribe to Conversation `onError` event.
     *
     * @category Events
     * @example
     * ```js
     * const uhlive = new Uhlive("my-token");
     * const conversation = uhlive.join("test");
     * conversation.onError((msg) => console.log(msg))
     * ```
     */
    onError(callback: (payload: any) => void): this;
    /**
     * This event is triggered when the backend send a final transcript.
     *
     * @category Events
     * @example
     * ```js
     * const uhlive = new Uhlive("my-token);
     * const myConversation = uhlive.join("my-conversation");
     * myConversation.onSegmentDecoded((transcript) => {
     *     // Do something with `transcript`...
     * });
     * ```
     */
    onSegmentDecoded(callback: (transcript: SegmentDecoded) => void): Conversation;
    /**
     * The `speaker_left` event is triggered when a speaker leaves, or more abruptly, closes its connection. This event is published after all remaining transcript events of this speaker have been published.
     *
     * @category Events
     * @example
     * ```js
     * const uhlive = new Uhlive("my-token);
     * const myConversation = uhlive.join("my-conversation");
     * myConversation.onSpeakerLeft((speaker) => {
     *     // Do something with `speaker`...
     * });
     * ```
     */
    onSpeakerLeft(callback: (speaker: string) => void): Conversation;
    /**
     * The `words_decoded` event is triggered when the backend sends an interim transcript. Following `words_decoded` events for the same audio are susceptible to be different, until a final transcript is sent with the `segment_decoded` event.
     *
     * @category Events
     * @example
     * ```js
     * const uhlive = new Uhlive("my-token);
     * const myConversation = uhlive.join("my-conversation");
     * myConversation.onWordsDecoded((transcript) => {
     *     // Do something with `transcript`...
     * });
     * ```
     */
    onWordsDecoded(callback: (transcript: SegmentDecoded) => void): Conversation;
    private askForPermissions;
    private generateSpeakerId;
    private sendMessage;
    private socketSend;
    private startRecording;
    private stopRecording;
    private validateConstructorParameters;
}
export declare type ConversationId = string;
/**
 * Optional parameters for Conversation class constructor.
 */
export interface ConversationOptions {
    /**
     * Send interim segments as well as the final segments.
     */
    interim_results?: boolean;
    /**
     * Specify which model to use to decode the audio.
     */
    model?: string;
    /**
     * Set to `true` if you don't want to send audio but only read.
     */
    readonly?: boolean;
    /**
     * Rescore the transcript result for better results.
     */
    rescoring?: boolean;
    /**
     * Speaker identifier.
     */
    speaker?: string;
}
/**
 * Transcript format emited by Uhlive-js.
 */
interface SegmentDecodedWord {
    /**
     * Confidence for the decoding of the word, from 0 to 1.
     */
    confidence: number;
    /**
     * Timestamp of the end of the word, in milliseconds.
     */
    end: number;
    /**
     * Length of the word, in milliseconds.
     */
    length: number;
    /**
     * Timestamp of the beginning of the word, in milliseconds.
     */
    start: number;
    /**
     * The decoded word.
     */
    word: string;
}
interface SegmentDecoded {
    /**
     * Timestamp of the end of the segment, in milliseconds.
     */
    end: number;
    /**
     * Length of the segment, in milliseconds.
     */
    length: number;
    /**
     * The id of the speaker.
     */
    speaker: string;
    /**
     * Timestamp of the beginning of the segment, in milliseconds.
     */
    start: number;
    /**
     * Concatenated words of the segment.
     */
    transcript: string;
    /**
     * Words decoded for the segment.
     */
    words: SegmentDecodedWord[];
}
export {};
